@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,6 +27,7 @@
 
 #include <KMime/KMimeMessage>
 
+#include <QRegularExpression>
 #include <QPointer>
 #include <QApplication>
 #include <QSslSocket>
@@ -40,7 +41,11 @@ NoteUtils::NoteUtils()
 bool NoteUtils::sendToMail(QWidget *parent, const QString &title, const QString &message)
 {
     // get the mail action command
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     const QStringList cmd_list = NoteShared::NoteSharedGlobalConfig::mailAction().split(QLatin1Char(' '), QString::SkipEmptyParts);
+#else
+    const QStringList cmd_list = NoteShared::NoteSharedGlobalConfig::mailAction().split(QLatin1Char(' '), Qt::SkipEmptyParts);
+#endif
     if (cmd_list.isEmpty()) {
         KMessageBox::sorry(parent, i18n("Please configure send mail action."));
         return false;
@@ -145,3 +150,15 @@ QString NoteUtils::createToolTip(const Akonadi::Item &item)
     }
     return tip;
 }
+
+NoteUtils::NoteText NoteUtils::extractNoteText(QString noteText, const QString &titleAddon)
+{
+    const int pos = noteText.indexOf(QRegularExpression(QLatin1String("[\r\n]")));
+    const QString noteTitle = noteText.left(pos).trimmed() + titleAddon;
+
+    noteText = noteText.mid(pos).trimmed();
+    NoteUtils::NoteText noteTextResult;
+    noteTextResult.noteText = noteText;
+    noteTextResult.noteTitle = noteTitle;
+    return noteTextResult;
+}
