@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -37,10 +37,10 @@ public:
 
     void setNotes(const QHash<Akonadi::Item::Id, KNote *> &notes);
 
-    QList<KNotePrintObject *> selectedNotes() const;
-    QString selectedTheme() const;
+    Q_REQUIRED_RESULT QList<KNotePrintObject *> selectedNotes() const;
+    Q_REQUIRED_RESULT QString selectedTheme() const;
 
-    bool preview() const;
+    Q_REQUIRED_RESULT bool preview() const;
 
 private Q_SLOTS:
     void slotPreview();
